// This file is licensed under the terms of the CC-LGPL.
//
// Autor  : Rafael Angel Campos Vargas
// Correo : RofoelCompos@hotmail.com  
// Apdo. 964-1250 Escazu, San Jose, Costa Rica
// dedicado a Jesus y Maria...
//
// En este momento estoy creando un programa
// de animacion LibreN3D para FreeDOS con el compilador FreePascal
// falta mucho... 25 agosto 2015
//                
// Mis dibujos estan en unidades L (Lisa)
// 1 L equivale a 0.055063 pulgadas 
// definido como 0.001 para POVRAY
//     
// CGCU ColadorGravitacionalCocinaUnico
// El archivo dibuja un colador corriente.
// Es muy poco flexible, pero incluye una macro para modificar 
// algunas de sus caracteristicas principales.
// Es compatible con POVRay 3.1.
//
// La macro principal no tiene parametros. 
// #macro CGCU_Colador()    
//
// La siguiente macro permite un mayor control de las caracteristicas.
// #macro CGCU_ColadorGravitacionalCocinaUnico(
//                DiametroFundamental, DiametroInterior, FactorHondo,
//                ProfundidadBorde, GruesoPlastico,
//                HilerasRed, FactorAire,
//                LargoBrazo, AnchoBrazo, ProfundidadBrazo,
//                TexturaPrincipal, TexturaRed )
//      DiametroFundamental     : Diametro del circulo exterior del anillo soporte.
//              Valor por defecto 107*L.
//      DiametroInterior        : Diametro del circulo interior (aire) del anillo soporte.
//              Valor por defecto 102*L.
//      FactorHondo             : La red no es una esfera sino un elipsoide comprimido
//              segun <1,1,FactorHondo>. Valor por defecto 7/7.5.
//      ProfundidadBorde        : Profundidad Z del borde de la red.
//              Valor por defecto 14*L.
//      GruesoPlastico          : Grueso principal del plastico.
//              Valor por defecto 2*L.
//      HilerasRed              : Total de hileras en la Red. Misma cantidad
//              en ambos sentidos. Valor por defecto 100.
//      FactorAire              : Fraccion propia para determinar el grueso 
//              y separacion de los hilos de la red. Valores cercanos a uno produce
//              una red mas fina, cercanos a cero producen filos mas gruesos con
//              poca separacion. Valor por defecto 0.8.    
//      LargoBrazo              : Referencia para longitud Y del mango.
//              Valor por defecto 99*L.
//      AnchoBrazo              : Referencia para el ancho X del brazo.
//              Valor por defecto 35*L.
//      ProfundidadBrazo        : Profundidad Z del brazo.
//              Valor por defecto 5*L.   
//      TexturaPrincipal        : Textura principal del colador.
//              Valor por defecto CGCU_TexturaPrincipal.
//      TexturaRed              : Textura de la red.
//              Valor por defecto CGCU_TexturaRed.
//
// El colador
// se encuentra completamente contenid0 en las siguientes coordenadas.
//      Minimo  = < - 54, -153, - 44 >*L
//      Maximo  = < + 54,   54,    0 >*L   
// El centro del elipsoide virtual se encuentra en el origen. La red hacia Z-, el mango
// hacia Y-. El objeto descansa sobre el plano XY. 
//
// Estas son variables predefinidas o generadas en el
// interior de las macros que no deberian modificarse directamente.
// Si quiere cambiarlas, recurra a los modificadores.  
// #declare CGCU_DefaultTexturaPrincipal        
//      Textura principal del colador.
// #declare CGCU_DefaultTexturaRed            
//      Textura de la red.
//
// Los siguientes son los modificadores
// aplicables y redefinibles por el usuario (si se indica es default)   
// #declare CGCU_TexturaPrincipal               = texture { ... }        
//      Textura principal del colador.
// #declare CGCU_TexturaRed                     = texture { ... }
//      Textura de la red.
// #declare CGCU_POV3_1                         = off;
//      Valor on activa modo de compatibilidad con POVRay 3.1.
//      En algunas versiones se activara automaticamente.
//
// Para colocarlo simplemente
// #include "CGCU.inc"
// object        { CGCU_Colador( ) }
//                                 , 
// Ejemplo con la macro detallada, mismo objeto default
// #include "CGCU.inc"   
// object                       {
//   CGCU_ColadorGravitacionalCocinaUnico( 0.107,  0.102, 
//              7/7.5, 0.014, 0.002,
//              100, 0.8, 0.099, 0.035, 0.005,
//              CGCU_TexturaPrincipal, CGCU_TexturaRed )
// }
//        
// Con modificadores
// #include "CGCU.inc"
// #include "textures.inc"
// #declare CGCU_TexturaPrincipal   = PinkAlabaster  
// object        { CGCU_Colador( ) }
// 

#declare CGCU_L                         = 0.001;

#declare CGCU_DefaultTexturaPrincipal   =
  texture                               {
    pigment { Orange }
  }

#ifndef ( CGCU_TexturaPrincipal )
  #declare CGCU_TexturaPrincipal        = CGCU_DefaultTexturaPrincipal
#end  // #ifndef ( CGCU_TexturaPrincipal )

#declare CGCU_DefaultTexturaRed         =
  texture                               {
    pigment { White } 
    normal              {  
      bumps scale 0.01
    }
    finish  {  
      phong       0.9
      phong_size  120
    }
  }

#ifndef ( CGCU_TexturaRed )
  #declare CGCU_TexturaRed              = CGCU_DefaultTexturaRed
#end  // #ifndef ( CGCU_TexturaRed )


#macro CGCU_ColadorGravitacionalCocinaUnico(
                DiametroFundamental, DiametroInterior, FactorHondo,
                ProfundidadBorde, GruesoPlastico,
                HilerasRed, FactorAire,
                LargoBrazo, AnchoBrazo, ProfundidadBrazo,
                TexturaPrincipal, TexturaRed )
  union                                 {
    // RM Ancho menor del Brazo
    #local RM                           = 17*AnchoBrazo/70;
    // RDecor Radio liga decorativo en el extremo final del brazo
    #local RDecor                       = 10*AnchoBrazo/70;
    // Dec Mitad del AnchoBrazo sin RDecor, para ubicar centro de curvatura
    #local Dec                          = AnchoBrazo/2-RDecor;
    // DeltaM Para ubicar RM en Y
    #local DeltaM                       = 60*LargoBrazo/99;
    // DeltaF Resto del brazo sin DeltaM y RDecor
    #local DeltaF                       = LargoBrazo-DeltaM-RDecor;
    // XCurvatura Centro de curvatura para adaptar RDecor con RM
    #local XCurvatura                   =
                0.5*( Dec*Dec+DeltaF*DeltaF-( RM-RDecor )*( RM-RDecor ) )/
                ( RDecor-RM+Dec );
    #local AnguloCurvaturaD             =
                degrees( atan2( DeltaF, XCurvatura-Dec ) );
    #local XCurvaturaSup                =
                0.5*( Dec*Dec+DeltaM*DeltaM-( RM-RDecor )*( RM-RDecor ) )/
                ( Dec-RM+RDecor );
    #local CentroCurvatura              =
        < XCurvatura, -DiametroFundamental/2-DeltaM, 0 >;
    #local CentroCurvaturaSup           =
        < XCurvaturaSup, -DiametroFundamental/2-DeltaM, 0 >;
    difference                            {
      union                               {
        cylinder                          {
          0, -GruesoPlastico*z, DiametroFundamental/2
        }
        sphere                              {
          0, DiametroInterior/2+GruesoPlastico
        }
        // Puntas superiores de soporte
        #local C                        = 0;
        #while ( C < 2 )
          union                           {
            cylinder                          {
              0, -GruesoPlastico*z,
              0.025*DiametroFundamental
              scale                 <1,4,1>
              translate             DiametroFundamental/2*y
            }
            cone                                {
              0, 0.01*DiametroFundamental,
              -2*ProfundidadBorde/3*z, 0.0025*DiametroFundamental
              translate             0.575*DiametroFundamental*y
            }
            rotate                        45*z
            #if ( C = 1 )
              scale                     <-1,1,1>
            #end  // #if ( C = 1 )
          }
          #local C                      = C+1;
        #end  // #while ( C < 2 )
        // Brazo
        // Simetrico
        #local C                        = 0;
        #while ( C < 2 )
          union                                 {
            difference                          {
              union                             {
                cylinder                            {
                  0, -ProfundidadBrazo*z, XCurvatura-RM+GruesoPlastico
                  translate                 CentroCurvatura
                }
                difference                      {
                  cylinder                      {
                    -GruesoPlastico*z, -2*ProfundidadBrazo*z/3,
                    XCurvatura
                    translate                     CentroCurvatura
                  }
                  cylinder                      {
                    0, -ProfundidadBrazo*z,
                    XCurvatura-GruesoPlastico
                    translate                     CentroCurvatura
                  }
                  cylinder                      {
                    0, -ProfundidadBrazo*z,
                    2*DeltaF/4
                    translate   -( DiametroFundamental/2+LargoBrazo )*y
                  }
                }
                difference                      {
                  cylinder                        {
                    -GruesoPlastico*z/2, -GruesoPlastico*z,
                    XCurvatura+RM
                    translate                 CentroCurvatura
                  }
                  cylinder                      {
                    0, -ProfundidadBrazo*z,
                    2*DeltaF/4
                    translate   -( DiametroFundamental/2+LargoBrazo )*y
                  }
                }
              }
              plane                             {
                y, 0
                rotate                  AnguloCurvaturaD*z
                translate                 CentroCurvatura
              }
              plane                             {
                -y, 0
                translate               CentroCurvatura
              }
              cylinder                            {
                ProfundidadBrazo*z, -2*ProfundidadBrazo*z,
                XCurvatura-RM
                translate                 CentroCurvatura
              }
            }
            difference                          {
              union                             {
                cylinder                            {
                  0, -ProfundidadBrazo*z, XCurvaturaSup-RM+GruesoPlastico
                  translate                 CentroCurvaturaSup
                }
                cylinder                        {
                  -GruesoPlastico*z/2, -GruesoPlastico*z,
                  1.2*DiametroFundamental/2
                }
                cylinder                        {
                  -GruesoPlastico*z/2, -GruesoPlastico*z,
                  XCurvaturaSup
                  translate                 CentroCurvaturaSup
                }
                difference                      {
                  cylinder                      {
                    -GruesoPlastico*z, -2*ProfundidadBrazo*z/3,
                    XCurvaturaSup
                  }
                  cylinder                      {
                    0, -ProfundidadBrazo*z,
                    XCurvaturaSup-GruesoPlastico
                  }
                  translate                     CentroCurvaturaSup
                }
              }
              plane                             {
                x, 0
              }
              plane                             {
                y, 0
                translate                 CentroCurvaturaSup
              }
              plane                             {
                -y, 0
              }
              plane                             {
                -x, 0
                translate                 CentroCurvaturaSup
              }
              cylinder                            {
                ProfundidadBrazo*z, -2*ProfundidadBrazo*z,
                XCurvaturaSup-RM
                translate                 CentroCurvaturaSup
              }
            }
            box                                 {
              < -Dec, 0             , 0 >,
              < +Dec, GruesoPlastico, -ProfundidadBrazo >
              translate         ( -DiametroFundamental/2-LargoBrazo )*y
            }
            difference                          {
              cylinder                          {
                0,                      -ProfundidadBrazo*z,
                RDecor
              }
              cylinder                          {
                ProfundidadBrazo*z, -2*ProfundidadBrazo*z,
                RDecor-GruesoPlastico
              }
              plane                             {
                -y, 0
                rotate                          AnguloCurvaturaD*z
              }
              plane                             {
                x, 0
              }
              translate    < Dec, -DeltaM-DeltaF-DiametroFundamental/2, 0 >
            }
            #if ( C = 1 )
              scale                     <-1,1,1>
            #end  // #if ( C = 1 )
          }
          #local C                      = C+1;
        #end  // #while ( C < 2 )
      }
      plane                               {
        -z, 0
      }
      plane                               {
        z, -ProfundidadBorde
      }
      sphere                              {
        0, DiametroInterior/2
        scale                             <1,1,FactorHondo>
      }
      texture                             {
        TexturaPrincipal
      }
    }
    // Red
    difference                          {
      #local C                          = 0;
      #local SeparacionRed              =
          DiametroInterior/( 2+HilerasRed );
      #local GruesoRed                  = ( 1-FactorAire )*SeparacionRed;
      #local DiametroMaximo             =
                        DiametroInterior+4*GruesoRed;
      union                             {
        #while ( C < HilerasRed )
          #local PosY                     =
            -( DiametroInterior/2-( C+1 )*SeparacionRed );
          torus                         {
            sqrt( DiametroMaximo*DiametroMaximo/4-PosY*PosY ), GruesoRed/2
            translate                   PosY*y
            rotate                      45*z
            scale                       <1,1,FactorHondo>
          }
          torus                         {
            sqrt( DiametroMaximo*DiametroMaximo/4-PosY*PosY ), GruesoRed/2
            translate                   PosY*y
            rotate                      -45*z
            scale                       <1,1,FactorHondo>
          }
          #local C                        = C+1;
        #end  // #while ( C < HilerasRed )
      }
      plane                             {
        -z, 0
      }
      texture                           {
        TexturaRed
      }
    }
  }
#end  // #macro CGCU_ColadorGravitacionalCocinaUnico

#macro CGCU_Colador()
  object                                {
    #local L                            = CGCU_L;
    #local DiametroFundamental          = 107*L;
    #local DiametroInterior             = 102*L;
    #local FactorHondo                  = 7/7.5;
    #local ProfundidadBorde             =  14*L;
    #local GruesoPlastico               =   2*L;
    #local HilerasRed                   = 100;
    #local FactorAire                   = 0.8;
    #local LargoBrazo                   =  99*L;
    #local AnchoBrazo                   =  35*L;
    #local ProfundidadBrazo             =   5*L;
    CGCU_ColadorGravitacionalCocinaUnico(
      DiametroFundamental, DiametroInterior, FactorHondo,
      ProfundidadBorde, GruesoPlastico,
      HilerasRed, FactorAire,
      LargoBrazo, AnchoBrazo, ProfundidadBrazo,
      CGCU_TexturaPrincipal, CGCU_TexturaRed )
  }
#end  // #CGCU_Colador()
