// This file is licensed under the terms of the CC-LGPL.
//
// Autor  : Rafael Angel Campos Vargas
// Correo : RofoelCompos@hotmail.com  
// Apdo. 964-1250 Escazu, San Jose, Costa Rica
// dedicado a Jesus y Maria...
//
// En este momento estoy creando un programa
// de animacion LibreN3D para FreeDOS con el compilador FreePascal
// falta mucho... 22 diciembre 2015
//                
// Mis dibujos estan en unidades L (Lisa)
// 1 L equivale a 0.055063 pulgadas 
// definido como 0.001 para POVRAY
//     
// PPHT PicoParaHombreTrabajador
// El archivo dibuja un pico corriente para agricultura.
// Es muy poco flexible, pero incluye una macro para modificar 
// algunas de sus caracteristicas principales.
// Es compatible con POVRay 3.1.
//
// La macro principal no tiene parametros. 
// #macro PPHT_Pico()    
//
// La siguiente macro permite un mayor control de las caracteristicas.
// #macro PPHT_PicoParaHombreTrabajador
//              ( LargoPico, GruesoPico, AltoMadera, GruesoMadera,
//                TexturaMetal, TexturaMadera )
//      LargoPico               : Largo del pico metalico. Valor por defecto 343*L.    
//      GruesoPico              : Grueso del pico metalico en Z. Valor por defecto 50*L.  
//      AltoMadera              : Alto total del pico. Valor por defecto 600*L.
//      GruesoMadera            : Grueso en Z de la madera. Valor por defecto 35*L.
//      TexturaMetal            : Textura para aplicar al metal. 
//              Valor por defecto PPHT_TexturaMetal.
//      TexturaMadera           : Textura del soporte de madera. 
//              Valor por defecto PPHT_TexturaMadera.
//
// El pico se encuentra completamente contenido en las siguientes coordenadas.
//      Minimo  = < -180, -600, - 25 >*L
//      Maximo  = <  164,    0,   25 >*L
// El eje del pico sobre el eje Y negativo. La cabeza hacia el origen, mirando hacia
// la direccion X+.
//
// Estas son variables predefinidas o generadas en el
// interior de las macros que no deberian modificarse directamente.
// Si quiere cambiarlas, recurra a los modificadores.  
// #declare PPHT_DefaultTexturaMetal      
//      Textura principal del pico.
// #declare PPHT_DefaultTexturaMadera            
//      Textura del soporte de madera.
//
// Los siguientes son los modificadores
// aplicables y redefinibles por el usuario (si se indica es default)   
// #declare PPHT_TexturaMetal                   = texture { ... }        
//      Textura principal del pico.
// #declare PPHT_TexturaMadera                  = texture { ... }
//      Textura del soporte de madera.
//
// Para colocarlo simplemente
// #include "PPHT.inc"
// object        { PPHT_Pico( ) }
//                                 , 
// Ejemplo con la macro detallada, mismo objeto default
// #include "PPHT.inc"   
// object                       {
//   PPHT_PicoParaHombreTrabajador(     
//          0.343, 0.050, 0.600, 0.035, PPHT_TexturaMetal, PPHT_TexturaMadera )
// }
//        
// Con modificadores
// #include "PPHT.inc"
// #include "textures.inc"
// #declare PPHT_TexturaMetal       = PinkAlabaster  
// object        { PPHT_Pico( ) }
// 


#declare PPHT_Lateral_USE_NORMAL_TRANSFORM      = 1;
#declare PPHT_Superior_USE_NORMAL_TRANSFORM         = 1;
#include "PPHT_AU1.inc"
#include "PPHT_AU2.inc"
#include "textures.inc"  
#include "woods.inc"

#declare PPHT_L                         = 0.001;

#declare PPHT_DefaultTexturaMetal       =
  texture                               {
    Rusty_Iron
  }
  texture                               {
    pigment                             {
      agate
      scale             0.01
      pigment_map                       {
        [ 0.0 Silver*0.3 ]
        [ 1.0 Silver*0.3 transmit 0.3 ]
      }
    }  
    finish                              {   
      metallic
    }
  }

#ifndef ( PPHT_TexturaMetal )
  #declare PPHT_TexturaMetal            = PPHT_DefaultTexturaMetal
#end  // #ifndef ( PPHT_TexturaMetal )

#declare PPHT_DefaultTexturaMadera      =
  texture                               {
    T_Wood11
    rotate  2 
    scale   0.5
  }

#ifndef ( PPHT_TexturaMadera )
  #declare PPHT_TexturaMadera           = PPHT_DefaultTexturaMadera
#end  // #ifndef ( PPHT_TexturaMadera )

#macro PPHT_PicoParaHombreTrabajador
                ( LargoPico, GruesoPico, AltoMadera, GruesoMadera,
                  TexturaMetal, TexturaMadera )
  union                                 {
    // Pico Metalico
    union                               {
      // Forma Pico Principal
      intersection                      {
        object                          {
          PPHT_Superior
        }
        object                          {
          PPHT_Lateral
          rotate        90*x
        }
        rotate                          180*x
        translate                       -0.05*y-0.025*x
        scale                           LargoPico
      }
      intersection                      {
        superellipsoid                    {
          <1,0.125>
          rotate                          90*x
          scale   <1.3,1,1>*GruesoPico/2
          translate                       -GruesoPico*y/2
        }
        cone                                    {
          y, 1, -y, 0.8
          scale   <1.3,1,1>*GruesoPico/2
          translate                       -GruesoPico*y/2
        }
      }
      texture                   { TexturaMetal }
    }
    union                             {
      superellipsoid                  {
        <1,0.2>
        rotate                        90*x
        matrix                <1,0,0,
                               0.05,1,0,
                               0,0,1,
                               0,0,0>
      }
      superellipsoid                  {
        <1,0.2>
        rotate                        90*x
        matrix                <1,0,0,
                               -0.05,1,0,
                               0,0,1,
                               0,0,0>
      }
      superellipsoid                  {
        <1,0.2>
        rotate                        90*x
        matrix                <1,0,0,
                               0,1,0,
                               0,0,1,
                               0,0,0>
      }
      scale <GruesoMadera,AltoMadera,GruesoMadera>/2
      translate               -AltoMadera/2*y
      texture         { TexturaMadera }
    }
  }
#end  // #macro PPHT_PicoParaHombreTrabajador

#macro PPHT_Pico()
  union                                 {
    #local L                            = PPHT_L;
    #local LargoPico                    = 343*L;
    #local GruesoPico                   =  50*L;
    #local AltoMadera                   = 600*L;
    #local GruesoMadera                 =  35*L;
    PPHT_PicoParaHombreTrabajador( LargoPico, GruesoPico,
                AltoMadera, GruesoMadera,
                PPHT_TexturaMetal, PPHT_TexturaMadera )
  }
#end  // #macro PPHT_Pico

