// This file is licensed under the terms of the CC-LGPL.
//
// Autor  : Rafael Angel Campos Vargas
// Correo : RofoelCompos@hotmail.com  
// Apdo. 964-1250 Escazu, San Jose, Costa Rica
// dedicado a Jesus y Maria...
//
// En este momento estoy creando un programa
// de animacion LibreN3D para FreeDOS con el compilador FreePascal
// falta mucho...  2 febrero 2016
//                
// Mis dibujos estan en unidades L (Lisa)
// 1 L equivale a 0.055063 pulgadas 
// definido como 0.001 para POVRAY
//     
// RFTC RefrigeradoraFriaTiempoCompleto
// El archivo dibuja una refrigeradora de uso domestico.
// Es muy poco flexible, pero incluye una macro para modificar 
// algunas de sus caracteristicas principales.
// Es compatible con POVRay 3.1.
//
// La macro principal tiene unicamente dos parametros  
// #macro RFTC_Refrigeradora( AnguloPuerta, AnguloHielera )
//      AnguloPuerta            : Angulo para abrir la puerta principal.
//      AnguloHielera           : Angulo para abrir puerta del congelador.
//
// La siguiente macro permite un mayor control de las caracteristicas.
// #macro RFTC_RefrigeradoraFriaTiempoCompleto( AnguloPuerta, AnguloHielera,
//                AltoFundamental, FrenteFundamental, ProfundidadFundamnetal,
//                AlturaHielera, PrimerMarco, AlturaSeparadoresNivel,
//                MarcoAislanteMenor, MarcoAislanteMayor,
//                BasePiso, GruesoDivisiones, GruesoPlastico,
//                EspacioInteriorPuerta, GruesoPuerta,
//                ArregloTexturas )
//      AnguloPuerta            : Angulo para abrir la puerta principal.
//      AnguloHielera           : Angulo para abrir puerta del congelador.
//      AltoFundamental         : Alto total de la refrigeradora. Valor
//              por defecto 1135*L;
//      FrenteFundamental       : Referencia para el frente X de la refrigeradora.
//              Valor por defecto 480*L.
//      ProfundidadFundamental  : Referencia para la profundidad Z del aparato.
//              Valor por defecto 390*L;
//      AlturaHielera           : Altura asignada a la hielera.
//              Valor por defecto 350*L;
//      PrimerMarco             : Marco metalico de la refrigeradora, parcialmente visible
//              al exterior. Valor por defecto 15*L;
//      AlturaSeparadoresNivel  : Dimension Y de la separacion principal con la hielera
//              y el piso. Valor por defecto 25*L.
//      MarcoAislanteMenor      : Valor por defecto del grueso de aislamiento termico
//              en su capa delgada. Valor por defecto 18*L.
//      MarcoAislanteMayor      : Valor por defecto del grueso de aislamiento termico
//              en su capa gruesa. Valor por defecto 43*L.
//      BasePiso                : Altura de las patas. Valor por defecto 25*L.
//      GruesoDivisiones        : Dimension Y de las divisiones internas.
//              Valor por defecto 7*L;
//      GruesoPlastico          : Grueso fundamental del material plastico.
//              Valor por defecto 2*L.
//      EspacioInteriorPuerta   : Referencia del espacio interno reservado para la puerta.
//              Valor por defecto 86*L.
//      GruesoPuerta            : Referencia para el grueso de la puerta eliminando curvatura.
//              Valor por defecto 40*L.  
//      ArregloTexturas         : Arreglo de 7 o mas texturas, que se aplicaran en la figura.
//              Se utilizaran unicamente las primeras siete:
//              { Lateral, Aislante, NivelInterior, Puerta, Hule, Enfriamiento, Gavetilla },
//              Para redefinir la textura se recomienda utilizar los siguientes indices,
//              con el objetivo de facilitar compatibilidad futura. Los indices
//              son los numeros del 0 al 6 en forma ascendente.
//                      RFTC_IndiceTexturaLateral       : Paredes laterales.
//                      RFTC_IndiceTexturaAislante      : Interior del refrigerador.
//                      RFTC_IndiceTexturaNivelInterior : Vidrio en las divisiones internas.
//                      RFTC_IndiceTexturaPuerta        : Principal de la puerta.
//                      RFTC_IndiceTexturaHule          : Hule entre la puerta y el refrigerador.
//                      RFTC_IndiceTexturaEnfriamiento  : Tuberia de enfriamiento exterior.
//                      RFTC_IndiceTexturaGavetilla     : Gavetilla para las verduras y 
//                                  otras en la puerta.
//
// La refrigeradora se encuentra completamente contenida dentro de las siguientes coordenadas.
//      Minimo  = < -255,    0,    0 >*L
//      Maximo  = <  245, 1135, -520 >*L
// Frente hacia Z-, gravedad hacia Y-. Piso en plano XZ, y probable pared en plano XY.
// El eje Y+ sirve como guia para casi centrar la estructura completa en su parte posterior.
//
// Estas son variables predefinidas o generadas en el
// interior de las macros que no deberian modificarse directamente.
// Si quiere cambiar sus efectos, recurra a los modificadores.  
// #declare RFTC_TotalTexturas                      = 7; 
//      Total de texturas minimo para el parametro ArregloTexturas.      
// #declare RFTC_DefaultTexturaLateral  
//      Textura para las paredes laterales. 
// #declare RFTC_DefaultTexturaAislante      
//      Textura para el interior del refrigerador.
// #declare RFTC_DefaultTexturaNivelInterior            
//      Textura para el vidrio de las separaciones internas.
// #declare RFTC_DefaultTexturaPuerta       
//      Textura principal para aplicar a la puerta.
// #declare RFTC_DefaultTexturHule
//      Textura para el hule que separa y protege la refrigeradora de la puerta.
// #declare RFTC_DefaultTexturaEnfriamiento             
//      Textura para los tubos de enfriamiento.   
// #declare RFTC_DefaultTexturaGavetilla            
//      Textura de la gavetilla para vegetales y otras de la puerta.  
// #declare RFTC_ArregloTexturas            
//      Arreglo que contiene las siete texturas. Puede ser utilizada como parametro.
//      No se afecta por los modificadores, si la modificacion es posterior a la inclusion
//      del archivo.
//
// Los siguientes son los modificadores
// aplicables y redefinibles por el usuario (si se indica es default)   
// #declare RFTC_TexturaLateral               = texture { ... } 
//      Textura para las paredes laterales. 
// #declare RFTC_TexturaAislante              = texture { ... }
//      Textura para el interior del refrigerador.
// #declare RFTC_TexturaNivelInterior         = texture { ... }   
//      Textura para el vidrio de las separaciones internas.
// #declare RFTC_TexturaPuerta                = texture { ... }
//      Textura principal para aplicar a la puerta.
// #declare RFTC_TexturaHule                  = texture { ... }
//      Textura para el hule que separa y protege la refrigeradora de la puerta.
// #declare RFTC_TexturaEnfriamiento          = texture { ... }  
//      Textura para los tubos de enfriamiento.   
// #declare RFTC_TexturaGavetilla             = texture { ... }
//      Textura de la gavetilla para vegetales y otras de la puerta.  
//
// Para colocarlo simplemente
// #include "RFTC.inc"
// object        { RFTC_Refrigeradora( 0, 0 ) }
//                           
// Ejemplo con la macro detallada, mismo objeto default
// #include "RFTC.inc"   
// object                       {
//   RFTC_RefrigeradoraFriaTiempoCompleto( 0, 0, 
//            1.135, 0.480, 0.390, 0.350, 0.015,
//            0.025, 0.018, 0.043, 0.025, 0.007, 
//            0.002, 0.086, 0.040, RFTC_ArregloTexturas )
// }
//                                                     
// Puede declarar su propio arreglo de texturas.
// #include "RFTC.inc"   
// #declare ArregloTexturas   = array [7]
//      { PinkAlabaster, PinkAlabaster, PinkAlabaster, PinkAlabaster,
//        PinkAlabaster, PinkAlabaster, PinkAlabaster }
// object                       {
//   RFTC_RefrigeradoraFriaTiempoCompleto( 0, 0, 
//            1.135, 0.480, 0.390, 0.350, 0.015,
//            0.025, 0.018, 0.043, 0.025, 0.007, 
//            0.002, 0.086, 0.040, ArregloTexturas )
// }
//
// Con modificadores
// #include "RFTC.inc"
// #include "textures.inc"
// #declare RFTC_TexturaLateral   = PinkAlabaster
// object        { RFTC_Cocina( 0, 0 ) }
// 
#include "textures.inc"
#include "stones.inc"

#declare RFTC_L                         = 0.001;

#if ( version < 3.2 )
  #ifndef( RFTC_POV3_1 )
    #declare RFTC_POV3_1        = on;
  #end
#else
  #ifndef( RFTC_POV3_1 )
    #declare RFTC_POV3_1        = off;
  #end
#end

#declare RFTC_TotalTexturas                     = 7;
#declare RFTC_IndiceTexturaLateral              = 0;
#declare RFTC_IndiceTexturaAislante             = 1;
#declare RFTC_IndiceTexturaNivelInterior        = 2;
#declare RFTC_IndiceTexturaPuerta               = 3;
#declare RFTC_IndiceTexturaHule                 = 4;
#declare RFTC_IndiceTexturaEnfriamiento         = 5;
#declare RFTC_IndiceTexturaGavetilla            = 6;

#declare RFTC_DefaultTexturaLateral     =
  texture                               {
    pigment                             { 
      color ( MidnightBlue+1.5*Black )/2.5
    }
    normal                              {
      bumps    
      scale       0.25
    }
    finish                              {   
      metallic
      #if ( RFTC_POV3_1 )
        phong 0.1
      #else
        phong albedo 0.1
      #end
      phong_size 60
    }
  }

#ifndef ( RFTC_TexturaLateral )
  #declare RFTC_TexturaLateral          = RFTC_DefaultTexturaLateral
#end  // #ifndef ( RFTC_TexturaLateral )

#declare RFTC_DefaultTexturaAislante    =
  texture                               {
    pigment                             { 
      dents 
      color_map                         { 
        [ 0.0 Quartz ]
        [ 1.0 White  ]                     
      }    
      scale   0.01
    } 
    normal                            {    
      gradient x 
      scale   0.011
    }              
    finish                            {
      #if ( RFTC_POV3_1 )
        phong 0.1
      #else
        phong albedo 0.1
      #end
      phong_size 40
    }
  }

#ifndef ( RFTC_TexturaAislante )
  #declare RFTC_TexturaAislante         = RFTC_DefaultTexturaAislante
#end  // #ifndef ( RFTC_TexturaAislante )

#declare RFTC_DefaultTexturaNivelInterior       =
  texture                                       {
    NBglass
  }

#ifndef ( RFTC_TexturaNivelInterior )
  #declare RFTC_TexturaNivelInterior    = RFTC_DefaultTexturaNivelInterior
#end  // #ifndef ( RFTC_TexturaNivelInterior )

#declare RFTC_DefaultTexturaPuerta              =
  texture                                       {
    pigment                                     {    
      LightSteelBlue
    }               
    normal                                      {   
      waves       scale 0.25
    }   
    finish                                    {   
      metallic 
      #if ( RFTC_POV3_1 )
        phong 0.1
      #else
        phong albedo 0.1
      #end
      phong_size 60
    }
  }

#ifndef ( RFTC_TexturaPuerta )
  #declare RFTC_TexturaPuerta           = RFTC_DefaultTexturaPuerta
#end  // #ifndef ( RFTC_TexturaPuerta )

#declare RFTC_DefaultTexturaGavetilla   =
  texture                                       {
    pigment { color ( Green+9*White )/10 transmit 0.80 } 
    normal    { gradient x scale 0.02 }
  }

#ifndef ( RFTC_TexturaGavetilla )
  #declare RFTC_TexturaGavetilla        = RFTC_DefaultTexturaGavetilla
#end  // #ifndef ( RFTC_TexturaGavetilla )

#declare RFTC_DefaultTexturaHule        =
  texture                               {
    Cork
  }
  texture                               {
    pigment                             {
      Gray10 transmit 0.1
    }
  }

#ifndef ( RFTC_TexturaHule )
  #declare RFTC_TexturaHule             = RFTC_DefaultTexturaHule
#end  // #ifndef ( RFTC_TexturaHule )

#declare RFTC_TexturaEnfriamiento       =
  texture                               {
    pigment                             {    
      granite
      pigment_map                   {    
        [ 0.0 Gray20 ]
        [ 1.0 Gray10 ]
      }
    }
    normal              {
      granite
    }                
    finish                {  
      metallic
      #if ( RFTC_POV3_1 )
        phong 0.1
      #else
        phong albedo 0.1
      #end
      phong_size 60
    }
    scale  0.01
  }

#ifndef ( RFTC_TexturaEnfriamiento )
  #declare RFTC_TexturaEnfriamiento     = RFTC_DefaultTexturaEnfriamiento
#end  // #ifndef ( RFTC_TexturaEnfriamiento )

#declare RFTC_ArregloTexturas              = array [ RFTC_TotalTexturas ]
#declare RFTC_ArregloTexturas[ RFTC_IndiceTexturaLateral ]         =
                                RFTC_TexturaLateral
#declare RFTC_ArregloTexturas[ RFTC_IndiceTexturaAislante ]        =
                                RFTC_TexturaAislante
#declare RFTC_ArregloTexturas[ RFTC_IndiceTexturaNivelInterior ]   =
                                RFTC_TexturaNivelInterior
#declare RFTC_ArregloTexturas[ RFTC_IndiceTexturaPuerta ]          =
                                RFTC_TexturaPuerta
#declare RFTC_ArregloTexturas[ RFTC_IndiceTexturaHule ]            =
                                RFTC_TexturaHule
#declare RFTC_ArregloTexturas[ RFTC_IndiceTexturaEnfriamiento ]    =
                                RFTC_TexturaEnfriamiento
#declare RFTC_ArregloTexturas[ RFTC_IndiceTexturaGavetilla ]       =
                                RFTC_TexturaGavetilla

#macro RFTC_RefrigeradoraFriaTiempoCompleto(AnguloPuerta, AnguloHielera,
                AltoFundamental, FrenteFundamental, ProfundidadFundamental,
                AlturaHielera, PrimerMarco, AlturaSeparadoresNivel,
                MarcoAislanteMenor, MarcoAislanteMayor,
                BasePiso, GruesoDivisiones, GruesoPlastico,
                EspacioInteriorPuerta, GruesoPuerta,
                ArregloTexturas )
  union                                 {
    #local TexturaLateral               =
                ArregloTexturas[ RFTC_IndiceTexturaLateral ]
    #local TexturaAislante              =
                ArregloTexturas[ RFTC_IndiceTexturaAislante ]
    #local TexturaNivelInterior         =
                ArregloTexturas[ RFTC_IndiceTexturaNivelInterior ]
    #local TexturaPuerta                =
                ArregloTexturas[ RFTC_IndiceTexturaPuerta ]
    #local TexturaHule                  =
                ArregloTexturas[ RFTC_IndiceTexturaHule ]
    #local TexturaEnfriamiento          =
                ArregloTexturas[ RFTC_IndiceTexturaEnfriamiento ]
    #local TexturaGavetilla             =
                ArregloTexturas[ RFTC_IndiceTexturaGavetilla ]
    difference                          {
      box                               {
        < -FrenteFundamental/2, BasePiso, ProfundidadFundamental >,
        < +FrenteFundamental/2, AltoFundamental, 0 >
      }
      box                               {
        < -FrenteFundamental/2+PrimerMarco,
          AltoFundamental-AlturaHielera+PrimerMarco,
          ProfundidadFundamental-PrimerMarco >,
        < +FrenteFundamental/2-PrimerMarco,
          AltoFundamental-PrimerMarco,
          -PrimerMarco >      
      }
      box                               {
        < -FrenteFundamental/2+PrimerMarco,
          BasePiso+AlturaSeparadoresNivel+PrimerMarco,
          ProfundidadFundamental-PrimerMarco >,
        < +FrenteFundamental/2-PrimerMarco,
          AltoFundamental-AlturaHielera-AlturaSeparadoresNivel-PrimerMarco,
          -PrimerMarco >
        texture   { TexturaAislante }  
      }      
    }
    // Paredes Aislantes del frio
    // Hielera
    union                               {
      difference                        {
        box                             {
          < -FrenteFundamental/2+PrimerMarco,
            AltoFundamental-AlturaHielera+PrimerMarco,
            ProfundidadFundamental-PrimerMarco >,
          < +FrenteFundamental/2-PrimerMarco,
            AltoFundamental-PrimerMarco,
            +PrimerMarco >
        }
        box                             {
          < -FrenteFundamental/2+PrimerMarco+MarcoAislanteMayor,
            AltoFundamental-AlturaHielera+PrimerMarco+MarcoAislanteMayor,
            ProfundidadFundamental-PrimerMarco-MarcoAislanteMayor >,
          < +FrenteFundamental/2-PrimerMarco-MarcoAislanteMayor,
            AltoFundamental-PrimerMarco-MarcoAislanteMayor,
            +PrimerMarco >
        }
        superellipsoid                  {
          <0.2,0.2>
          scale    < FrenteFundamental/2-PrimerMarco-MarcoAislanteMenor,
                     AlturaHielera/2-PrimerMarco-MarcoAislanteMenor,
                     ProfundidadFundamental/2-PrimerMarco-MarcoAislanteMenor >
          translate                     ( ProfundidadFundamental/2 )*z
                        +( AltoFundamental-AlturaHielera/2 )*y
        }
        prism                           {
          conic_sweep
          linear_spline
          0, 1.1, 5,
          <1,1>,<1,-1>,<-1,-1>,<-1,1>,<1,1>
          rotate                        -90*x
          scale                         < FrenteFundamental/2-PrimerMarco,
                                          AlturaHielera/2-PrimerMarco,
                                   ProfundidadFundamental/2-PrimerMarco >
          translate                     ( ProfundidadFundamental/2 )*z
                        +( AltoFundamental-AlturaHielera/2 )*y
        }
      }
      #local C                          = 0;
      #while ( C < 9 )
        cylinder                        {
          -x, x, 1
          scale < FrenteFundamental/2-PrimerMarco,
                  GruesoDivisiones/2, GruesoDivisiones/2 >
          translate                     ( ProfundidadFundamental/2 )*z
                        +( AltoFundamental-AlturaHielera/2 )*y
          translate     ( C-4 )*( ProfundidadFundamental/2-PrimerMarco
                                        -MarcoAislanteMayor )*z/5
        }
        #local C                        = C+1;
      #end  // #while ( C < 0 )
      texture                           {
        TexturaAislante
      }
    }
    // Alimentos Frios
    #local AlturaFria                   =
        AltoFundamental-BasePiso-AlturaHielera-2*AlturaSeparadoresNivel;
    union                               {
      difference                        {
        box                             {
          < -FrenteFundamental/2+PrimerMarco,
            BasePiso+AlturaSeparadoresNivel+PrimerMarco,
            ProfundidadFundamental-PrimerMarco >,
          < +FrenteFundamental/2-PrimerMarco,
            AltoFundamental-AlturaHielera-AlturaSeparadoresNivel-PrimerMarco,
            +PrimerMarco >
        }
        box                             {
          < -FrenteFundamental/2+PrimerMarco+MarcoAislanteMenor,
            BasePiso+AlturaSeparadoresNivel+PrimerMarco+MarcoAislanteMenor,
            ProfundidadFundamental-PrimerMarco-MarcoAislanteMenor >,
          < +FrenteFundamental/2-PrimerMarco-MarcoAislanteMenor,
            AltoFundamental-AlturaHielera-AlturaSeparadoresNivel-PrimerMarco
            -MarcoAislanteMenor,
            +PrimerMarco >
        }
        superellipsoid                  {
          <0.2,0.2>
          scale                         < FrenteFundamental/2-PrimerMarco,
                                          AlturaFria/2-PrimerMarco,
                                   ProfundidadFundamental/2-PrimerMarco >
                                   -MarcoAislanteMenor/2
          translate                     ( ProfundidadFundamental/2 )*z
                        +( BasePiso+AlturaSeparadoresNivel+AlturaFria/2 )*y
        }
        prism                           {
          conic_sweep
          linear_spline
          0, 1.1, 5,
          <1,1>,<1,-1>,<-1,-1>,<-1,1>,<1,1>
          rotate                        -90*x
          scale                         < FrenteFundamental/2-PrimerMarco,
                                          AlturaFria/2-PrimerMarco,
                                   ProfundidadFundamental/2-PrimerMarco >
          translate                     ( ProfundidadFundamental/2 )*z
                        +( BasePiso+AlturaSeparadoresNivel+AlturaFria/2 )*y
        }
      }
      #local C                          = 0;
      #while ( C < 3 )
        union                           {
          difference                    {
            superellipsoid              {
              <0.2,0.2>
            }
            box                         {
              -1, 1
              scale             < 0.9, 1.1, 0.9 >
            }
          }
          box                         {
            -1, 1
            scale             < 0.9, 0.75, 0.9 >
            texture                     {
              TexturaNivelInterior
            }
          }
          scale                         < FrenteFundamental/2-PrimerMarco,
                                            GruesoDivisiones,
                                     ProfundidadFundamental/2-PrimerMarco >
                                     -< MarcoAislanteMenor/2, 0,
                                        EspacioInteriorPuerta >
          translate                     ( ProfundidadFundamental/2 )*z
                        +( BasePiso+AlturaSeparadoresNivel+AlturaFria/2 )*y
          translate      ( C-1 )*( AlturaFria-MarcoAislanteMenor )*y/4
          #if ( C = 0 )
            translate    0.2*( AlturaFria-MarcoAislanteMenor )*y/4
          #end  // #if (  C = 0
        }
        #local C                        = C+1;
      #end  // #while ( C < 2 )
      // RecipienteInferior
      union                             {
        difference                      {
          merge                         {
            superellipsoid              {
              <0.2,0.2>
              scale                     <0.9,1,0.9>
            }
            superellipsoid              {
              <0.2,0.2>
              scale                     <1,0.5,1>
            }
          }
          union                         {
            superellipsoid              {
              <0.2,0.2>
              scale                     <0.9,1,0.9>
            }
            superellipsoid              {
              <0.2,0.2>
              scale                     <1,0.5,1>
            }
            scale                       0.95
          }
          plane                         {
            -y, 0.0
          }
          translate                     y
        }
        scale                       < FrenteFundamental/2-PrimerMarco
                        -MarcoAislanteMayor,
                ( 0.30*( AlturaFria-MarcoAislanteMenor )
                 -MarcoAislanteMayor-GruesoDivisiones ),
                   ProfundidadFundamental/2-PrimerMarco-MarcoAislanteMenor >
        translate               ( BasePiso+AlturaSeparadoresNivel+PrimerMarco+
                                       MarcoAislanteMayor )*y
        translate               ProfundidadFundamental/2*z
        texture                         {
          TexturaGavetilla
        }
      }
      // Decoraciones de la pared interior
      difference                        {
        union                           {
          difference                    {
            sphere                          {
              0, 1
            }
            sphere                      {
              -1, 0.5
            }
            torus                       {
              0.5, 0.25
              translate         -y/sqrt( 2 )
            }
            scale       min( ProfundidadFundamental, FrenteFundamental )/3
            scale               <1,0.75,1>
            translate                   AlturaFria*y
          }
          superellipsoid                {
            <0.3, 0.3>
            scale               < FrenteFundamental/3,
                                  AlturaFria*0.4, EspacioInteriorPuerta/2 >
            translate
               ( ProfundidadFundamental/2-PrimerMarco-MarcoAislanteMenor )*z
          }
          cylinder                      {
            -x, x, 1
            scale       < FrenteFundamental, AlturaFria/10, AlturaFria/30 >
            translate   AlturaFria/2*y+
               ( ProfundidadFundamental/2 )*z
          }
          cylinder                      {
            -x, x, 1
            scale       < FrenteFundamental, AlturaFria/10, AlturaFria/30 >
            translate   3*AlturaFria/4*y+
               ( ProfundidadFundamental/2 )*z
          }
        }
        box                             {
          -1, 1
          inverse
          scale         < FrenteFundamental/2, AlturaFria/2,
                          ProfundidadFundamental/2 >-MarcoAislanteMenor
          translate                     AlturaFria/2*y
        }
        translate          ( BasePiso+AlturaSeparadoresNivel+PrimerMarco )*y
        translate               ProfundidadFundamental/2*z
        texture                         {
          TexturaAislante
        }
      }
      texture                           {
        TexturaAislante
      }
    }
    // Separador Niveles
    #local ExcesoPuerta                 = 28/40*GruesoPuerta;
    #local AirePuerta                   = PrimerMarco/3;
    #local C                            = 0;
    #while ( C < 2 )
      union                             {
        box                             {
          < -FrenteFundamental/2, 0, 0 >,
          < +FrenteFundamental/2, AlturaSeparadoresNivel, -GruesoPuerta >
        }
        cylinder                        {
          0, y, 1
          scale                         < FrenteFundamental/2,
                                          AlturaSeparadoresNivel,
                                          ExcesoPuerta >
          translate                     -GruesoPuerta*z
        }
        translate                       BasePiso*y
        #if ( C =1 )
          translate             ( AlturaFria+AlturaSeparadoresNivel )*y
        #end  // #if ( C = 1 )
      }
      #local C                          = C+1;
    #end  // #while ( C < 2 )
    // Puertas
    #local GruesoHule                   = GruesoPuerta/4;
    #local PosicionManija               = 0.1*AlturaFria;
    // Cilindro Giro
    cylinder                            {
      BasePiso*y, AltoFundamental*y, ( GruesoPuerta-GruesoHule )/8
      translate                      -( GruesoPuerta+GruesoHule )/2*z
      translate      ( FrenteFundamental/2-( GruesoPuerta-GruesoHule )/2 )*x
    }
    // Diseno GavetillaPuerta
    #local GavetillaPuerta              =
      union                             {
        difference                      {
          superellipsoid                {
            <0.2,0.2>
            scale         < FrenteFundamental/2-PrimerMarco-MarcoAislanteMenor,
                          AlturaFria/10,
                          GruesoPuerta-GruesoHule+0.75*EspacioInteriorPuerta >
          }
          superellipsoid                {
            <0.2,0.2>
            scale         < FrenteFundamental/2-PrimerMarco-GruesoPlastico-
                               MarcoAislanteMenor,
                          AlturaFria/10-GruesoPlastico,
                          GruesoPuerta-GruesoHule+0.75*EspacioInteriorPuerta
                          -GruesoPlastico >
          }
          plane                         {
            -y, 0
          }
          plane                         {
            z, 0
          }
          texture                       {
            TexturaGavetilla
          }
        }
      }
    #local GavetillaHielera             =
      union                             {
        difference                      {
          superellipsoid                {
            <0.2,0.2>
            scale         < FrenteFundamental/2-PrimerMarco-MarcoAislanteMayor,
                          AlturaFria/12,
                          GruesoPuerta-GruesoHule+0.75*EspacioInteriorPuerta >
          }
          superellipsoid                {
            <0.2,0.2>
            scale         < FrenteFundamental/2-PrimerMarco-GruesoPlastico-
                               MarcoAislanteMayor,
                          AlturaFria/12-GruesoPlastico,
                          GruesoPuerta-GruesoHule+0.75*EspacioInteriorPuerta
                          -GruesoPlastico >
          }
          plane                         {
            -y, 0
          }
          plane                         {
            z, 0
          }
          texture                       {
            TexturaGavetilla
          }
        }
      }
    // Puerta Inferior
    union                               {
      difference                        {
        union                           {
          union                         {
            box                           {
              < -FrenteFundamental/2, 0, -GruesoHule   >,
              < +FrenteFundamental/2, AlturaFria-2*AirePuerta-PrimerMarco,
              -GruesoPuerta >
            }
            cylinder                      {
              0, y, 1
              scale               < FrenteFundamental/2,
                        AlturaFria-2*AirePuerta-PrimerMarco, ExcesoPuerta >
              translate           -GruesoPuerta*z
            }
            translate         PrimerMarco/2*y
            texture           { TexturaPuerta }
          }
          #local C                      = 0;
          #while ( C < 2 )
            union                         {
              box                           {
                < -FrenteFundamental/2, 0, -GruesoHule   >,
                < +FrenteFundamental/2, PrimerMarco, -GruesoPuerta >
              }
              cylinder                      {
                0, PrimerMarco*y, 1
                scale               < FrenteFundamental/2, 1, 1.01*ExcesoPuerta >
                translate           -GruesoPuerta*z
              }
              scale             < 1.01, 1, 1 >
              translate C*( AlturaFria-PrimerMarco-2*AirePuerta )*y
            }
            #local C                    = C+1;
          #end  // #while ( C < 2 )
          // Hule
          union                                 {
            #local C                    = 0;
            #local TotalBandas          = 7;
            #while ( C < TotalBandas )
              #if ( mod( C, 2 ) = 0 )
                #local ContraccionHule  = PrimerMarco/3;
              #else  // #else ( mod( C, 2 ) = 0 )
                #local ContraccionHule  = PrimerMarco/2;
              #end   // #else ( mod( C, 2 ) = 0 )
              box                       {
                < -FrenteFundamental/2+ContraccionHule, ContraccionHule, 0 >,
                < +FrenteFundamental/2-ContraccionHule,
                  AlturaFria-2*AirePuerta-2*ContraccionHule,
                  -GruesoHule/TotalBandas >
                translate               -C*GruesoHule/TotalBandas*z
              }
              #local C                  = C+1;
            #end  // #while ( C < 7 )
            texture             { TexturaHule }
          }
          // Manija
          difference                        {
            torus                           {
              0.85,
              0.15
              scale        < FrenteFundamental/4,
                             AlturaFria/8, 3*ExcesoPuerta/2 >
            }
            cylinder                        {
              -y, y, 0.85
              scale        < FrenteFundamental/4,
                             AlturaFria/8, 3*ExcesoPuerta/2 >
            }
            plane                           {
              -z, -GruesoPuerta+GruesoHule
            }
            translate              < -1.15*1*FrenteFundamental/4,
                            AlturaFria-PosicionManija,
                            -GruesoPuerta >
    
          }
        }
        superellipsoid                  {
          <0.1,0.1>
          scale         < FrenteFundamental/2-PrimerMarco,
                          AlturaFria/2-AirePuerta-PrimerMarco,
                          GruesoPuerta >
          translate                     AlturaFria/2*y
          texture                       {
            TexturaAislante
          }
        }
      }
      // BordeInteriorPuerta
      difference                        {
        prism                           {
          conic_sweep
          0, 2, 5,
          <1,1>,<1,-1>,<-1,-1>,<-1,1>,<1,1>
          rotate                        -90*x
          scale                         < FrenteFundamental/2-PrimerMarco,
                                          AlturaFria/2-PrimerMarco,
                                   ProfundidadFundamental/2-PrimerMarco >
        }
        box                             {
          -1, 1
          inverse
          scale                         < FrenteFundamental/2-PrimerMarco,
                                          AlturaFria/2-PrimerMarco,
                                   ProfundidadFundamental/2-PrimerMarco >
        }
        box                             {
          -1, 1
          scale       < FrenteFundamental/2-PrimerMarco-MarcoAislanteMenor,
                        AlturaFria/2-PrimerMarco-MarcoAislanteMenor,
                                   ProfundidadFundamental >
        }
        translate            ( ProfundidadFundamental/2-GruesoHule )*z
                        +( AlturaFria/2-AirePuerta )*y
        texture                         {
          TexturaAislante
        }
      }
      // GavetillaPuerta
      #local C                          = 0;
      #while ( C < 2 )
        object                          {
          GavetillaPuerta
          translate                     -GruesoPuerta*z
          translate                     0.8*AlturaFria*y
          translate                     -C*0.3*AlturaFria*y
        }
        #local C                        = C+1;
      #end  // #while ( C < 2 )
      box                               {
        < -FrenteFundamental/2+PrimerMarco, 0, 0 >,
        < +FrenteFundamental/2-PrimerMarco, GruesoPlastico,
          -GruesoPuerta >
        translate               0.25*AlturaFria*y  
        texture             { TexturaAislante }
      }
      translate                      +( GruesoPuerta+GruesoHule )/2*z
      translate     -( FrenteFundamental/2-( GruesoPuerta-GruesoHule )/2 )*x
      rotate                         -AnguloPuerta*y
      translate                      -( GruesoPuerta+GruesoHule )/2*z
      translate      ( FrenteFundamental/2-( GruesoPuerta-GruesoHule )/2 )*x
      translate         ( BasePiso+AlturaSeparadoresNivel+AirePuerta )*y
    }
    // PuertaSuperior
    union                               {
      difference                        {
        union                           {
          union                         {
            box                           {
              < -FrenteFundamental/2, 0, -GruesoHule   >,
              < +FrenteFundamental/2, AlturaHielera-AirePuerta-PrimerMarco,
              -GruesoPuerta >
            }
            cylinder                      {
              0, y, 1
              scale               < FrenteFundamental/2,
                        AlturaHielera-AirePuerta-PrimerMarco, ExcesoPuerta >
              translate           -GruesoPuerta*z
            }
            translate         PrimerMarco/2*y
            texture           { TexturaPuerta }
          }
          #local C                      = 0;
          #while ( C < 2 )
            union                         {
              box                           {
                < -FrenteFundamental/2, 0, -GruesoHule   >,
                < +FrenteFundamental/2, PrimerMarco, -GruesoPuerta >  
              }
              cylinder                      {
                0, PrimerMarco*y, 1
                scale               < FrenteFundamental/2, 1, 1.01*ExcesoPuerta >
                translate           -GruesoPuerta*z
              }
              scale             < 1.01, 1, 1 >
              translate C*( AlturaHielera-PrimerMarco-AirePuerta )*y
            }
            #local C                    = C+1;
          #end  // #while ( C < 2 )
          // Hule
          union                                 {
            #local C                    = 0;
            #local TotalBandas          = 7;
            #while ( C < TotalBandas )
              #if ( mod( C, 2 ) = 0 )
                #local ContraccionHule  = PrimerMarco/3;
              #else  // #else ( mod( C, 2 ) = 0 )
                #local ContraccionHule  = PrimerMarco/2;
              #end   // #else ( mod( C, 2 ) = 0 )
              box                       {
                < -FrenteFundamental/2+ContraccionHule, ContraccionHule, 0 >,
                < +FrenteFundamental/2-ContraccionHule,
                  AlturaHielera-AirePuerta-2*ContraccionHule,
                  -GruesoHule/TotalBandas >
                translate               -C*GruesoHule/TotalBandas*z
              }
              #local C                  = C+1;
            #end  // #while ( C < 7 )
            texture             { TexturaHule }
          }
          // Manija
          difference                        {
            torus                           {
              0.85,
              0.15
              scale        < FrenteFundamental/4,
                             AlturaFria/8, 3*ExcesoPuerta/2 >
            }
            cylinder                        {
              -y, y, 0.85
              scale        < FrenteFundamental/4,
                             AlturaFria/8, 3*ExcesoPuerta/2 >
            }
            plane                           {
              -z, -GruesoPuerta+GruesoHule
            }
            translate              < -1.15*1*FrenteFundamental/4,
                            +PosicionManija,
                            -GruesoPuerta >
    
          }
        }
        superellipsoid                  {
          <0.1,0.1>
          scale         < FrenteFundamental/2-PrimerMarco,
                          AlturaHielera/2-AirePuerta/2-PrimerMarco,
                          GruesoPuerta >
          translate                     ( AlturaHielera-PrimerMarco )/2*y
          texture                       {
            TexturaAislante
          }
        }
      }
      // BordeInteriorPuerta
      difference                        {
        prism                           {
          conic_sweep
          0, 2, 5,
          <1,1>,<1,-1>,<-1,-1>,<-1,1>,<1,1>
          rotate                        -90*x
          scale                         < FrenteFundamental/2-PrimerMarco,
                                          AlturaHielera/2-PrimerMarco,
                                   ProfundidadFundamental/4 >
        }
        box                             {
          -1, 1
          inverse
          scale                         < FrenteFundamental/2-PrimerMarco,
                                          AlturaHielera/2-PrimerMarco,
                                   ProfundidadFundamental/4 >
        }
        box                             {
          -1, 1
          scale       < FrenteFundamental/2-PrimerMarco-MarcoAislanteMayor,
                        AlturaHielera/2-2*PrimerMarco-MarcoAislanteMayor,
                                   ProfundidadFundamental >
        }
        translate            ( ProfundidadFundamental/4-GruesoHule )*z
                        +( AlturaHielera/2-AirePuerta/2 )*y
        texture                         {
          TexturaAislante
        }
      }
      // GavetillaPuerta
      #local C                          = 0;
      #while ( C < 2 )
        object                          {
          GavetillaHielera
          translate                     -GruesoPuerta*z
          translate                     0.3*AlturaHielera*y
          translate                     C*0.3*AlturaHielera*y
        }
        #local C                        = C+1;
      #end  // #while ( C < 2 )
      box                               {
        < -FrenteFundamental/2+PrimerMarco, 0, 0 >,
        < +FrenteFundamental/2-PrimerMarco, GruesoPlastico,
          -GruesoPuerta >
        translate               0.7*AlturaHielera*y
        texture   { TexturaAislante }  
      }
      translate                      +( GruesoPuerta+GruesoHule )/2*z
      translate     -( FrenteFundamental/2-( GruesoPuerta-GruesoHule )/2 )*x
      rotate                         -AnguloHielera*y
      translate                      -( GruesoPuerta+GruesoHule )/2*z
      translate      ( FrenteFundamental/2-( GruesoPuerta-GruesoHule )/2 )*x
      translate         ( AltoFundamental-AlturaHielera+AirePuerta )*y
    }
    // Enfriamiento
    union                               {
      difference                        {
        cylinder                        {
          ( BasePiso+4*PrimerMarco )*y,
          ( BasePiso+AlturaFria )*y, 1
        }
        cylinder                        {
          ( BasePiso+4*PrimerMarco )*y,
          ( BasePiso+AlturaFria )*y, 0.975
        }
        plane                           {
          z, -0.01
        }
        scale         < FrenteFundamental/2-3*PrimerMarco, 1,
                          ProfundidadFundamental/8 >
        texture                         {
          brick
          texture                       {
            TexturaEnfriamiento
          }
          texture                       {
            pigment { Clear }
          }
          rotate                45*z
          scale 0.01
        }
      }    
      cylinder                          {   
        0, 0.625*y, 1                                
        
        scale         < ProfundidadFundamental/18, AltoFundamental-BasePiso,
                          ProfundidadFundamental/18 >  
        translate  ( BasePiso+1*AltoFundamental/3 )*y
      }
      cylinder                          {   
        0, 0.625*y, 1                                
        
        scale         < ProfundidadFundamental/18, AltoFundamental-BasePiso,
                          ProfundidadFundamental/18 >  
        translate  ( BasePiso+1*AltoFundamental/3 )*y+0.4*FrenteFundamental*x
      }
      cylinder                          {   
        0, 0.625*y, 1                                
        
        scale         < ProfundidadFundamental/18, AltoFundamental-BasePiso,
                          ProfundidadFundamental/18 >  
        translate  ( BasePiso+1*AltoFundamental/3 )*y-0.4*FrenteFundamental*x
      }
      // Patas
      #local C                          = 0;
      #while ( C < 4 )
        union                           {
          box                           {
            <0,0,0>,
            <FrenteFundamental/10,BasePiso,FrenteFundamental/10>
          }
          translate     -FrenteFundamental/2*x*0.975
                        -ProfundidadFundamental/2*z*0.975
          #if ( mod( C, 2 ) = 0 )
            scale <-1,1,1>
          #end  // #if ( mod( C, 2 ) = 0 )
          #if ( div( C, 2 ) = 0 )
            scale <1,1,-1>
          #end  // #if ( div( C, 2 ) = 0 )
          translate     -ProfundidadFundamental/2*z
        }
        #local C                        = C+1;
      #end  // #while ( C < 4 )
      translate                 ProfundidadFundamental*z
    }
    translate                           -ProfundidadFundamental*z
    translate                           -ProfundidadFundamental*z/8 // Enfriamiento
    texture                             {
      TexturaLateral
    }
  }
#end  // #macro RFTC_RefrigeradoraFriaTiempoCompleto

#macro RFTC_Refrigeradora( AnguloPuerta, AnguloHielera )
  object                                {
    #local L                            = RFTC_L;
    #local AltoFundamental              = 1135*L;
    #local FrenteFundamental            =  480*L;
    #local ProfundidadFundamental       =  390*L;
    #local AlturaHielera                =  350*L;
    #local PrimerMarco                  =   15*L;
    #local AlturaSeparadoresNivel       =   25*L;
    #local MarcoAislanteMenor           =   18*L;
    #local MarcoAislanteMayor           =   43*L;
    #local BasePiso                     =   25*L;
    #local GruesoDivisiones             =    7*L;
    #local GruesoPlastico               =    2*L;
    #local EspacioInteriorPuerta        =   86*L;
    #local GruesoPuerta                 =   40*L;
    #local ArregloTexturas              = array [ RFTC_TotalTexturas ]
    #local ArregloTexturas[ RFTC_IndiceTexturaLateral ]         =
                                RFTC_TexturaLateral
    #local ArregloTexturas[ RFTC_IndiceTexturaAislante ]        =
                                RFTC_TexturaAislante
    #local ArregloTexturas[ RFTC_IndiceTexturaNivelInterior ]   =
                                RFTC_TexturaNivelInterior
    #local ArregloTexturas[ RFTC_IndiceTexturaPuerta ]          =
                                RFTC_TexturaPuerta
    #local ArregloTexturas[ RFTC_IndiceTexturaHule ]            =
                                RFTC_TexturaHule
    #local ArregloTexturas[ RFTC_IndiceTexturaEnfriamiento ]    =
                                RFTC_TexturaEnfriamiento
    #local ArregloTexturas[ RFTC_IndiceTexturaGavetilla ]       =
                                RFTC_TexturaGavetilla
    RFTC_RefrigeradoraFriaTiempoCompleto( AnguloPuerta, AnguloHielera,
        AltoFundamental, FrenteFundamental, ProfundidadFundamental,
        AlturaHielera, PrimerMarco, AlturaSeparadoresNivel,
        MarcoAislanteMenor, MarcoAislanteMayor,
        BasePiso, GruesoDivisiones, GruesoPlastico,
        EspacioInteriorPuerta, GruesoPuerta,
        ArregloTexturas )
  }
#end  // #macro RFTC_Refrigeradora()
