// This file is licensed under the terms of the CC-LGPL.
//
// Autor  : Rafael Angel Campos Vargas
// Correo : RofoelCompos@hotmail.com  
// Apdo. 964-1250 Escazu, San Jose, Costa Rica
// dedicado a Jesus y Maria...
//
// En este momento estoy creando un programa
// de animacion LibreN3D para FreeDOS con el compilador FreePascal
// falta mucho...  16 junio 2015
//                
// Mis dibujos estan en unidades L (Lisa)
// 1 L equivale a 0.055063 pulgadas 
// definido como 0.001 para POVRAY
//     
// SPRD SemaforoPeatonalRojoDetener
// El archivo dibuja un semaforo para cruce peatonal corriente.
// Es muy poco flexible, pero incluye una macro para modificar 
// algunas de sus caracteristicas principales.
// Es compatible con POVRay 3.1.
//
// La macro principal tiene cuatro parametros. 
// #macro SPRD_Semaforo( IzquierdoDerecho, BanderaRed,
//                        BanderaGreen, AnguloSemaforo )
//      IzquierdoDerecho        : "true" dibuja el semaforo con la caja hacia X-,
//              "false" hacia X+.                                               
//      BanderaRed              : "true" enciende la luz superior roja.
//      BanderaGreen            : "true" encienda la luz inferior verde.
//      AnguloSemaforo          : Angulo en grados de giro de la caja de luz.
//
// La siguiente macro permite un mayor control de las caracteristicas.
// #macro SPRD_SemaforoPeatonalRojoDetener(
//          IzquierdoDerecho, BanderaRed, BanderaGreen, AnguloSemaforo,
//          AltoFundamental, GruesoLateral, CajaLuz, AltoBoton,
//          TexturaPrincipal, TexturaOscura, TexturaTornillo, TexturaBoton )
//      IzquierdoDerecho        : "true" dibuja el semaforo con la caja hacia X-,
//              "false" hacia X+.                                               
//      BanderaRed              : "true" enciende la luz superior roja.
//      BanderaGreen            : "true" encienda la luz inferior verde.
//      AnguloSemaforo          : Angulo en grados de giro de la caja de luz.
//      AltoFundamental         : Alto del semaforo. Valor por  defecto 1975*L. 
//      GruesoLateral           : Grueso lateral del poste de semaforo. 
//              Valor por defecto 50*L.
//      CajaLuz                 : Vector 3D para dimensionar la caja de luces del semaforo.
//              Valor por defecto < 280, 420, 100 >*L.                           
//      AltoBoton               : Altura del boton para cambiar de luz.
//              Valor por defecto 800*L.
//      TexturaPrincipal        : Textura principal a aplicar al semaforo.
//              Valor por defecto SPRD_TexturaPrincipal.
//      TexturaOscura           : Textura para la caja oscura de luces.  
//              Las luces se ven claramente gracias al contraste del fondo.
//              Valor por defecto SPRD_TexturaOscura. 
//      TexturaTornillo         : Textura a aplicar a los tornillos.
//              Valor por defecto SPRD_TexturaTornillo.
//      TexturaBoton            : Textura a aplicar al boton.
//              Valor por defecto SPRD_TexturaBoton.
//      
// El semaforo con parametros <true,true,false,0> tiene las siguientes dimensiones.
//      Minimo  = < -390,    0, -190 >*L
//      Maximo  = <    0, 1975,   50 >*L 
// El parametro IzquierdoDerecho produce un resultado parecido a un scale <-1,1,1>;
// pero el angulo de rotacion es independiente de este parametro.
// El semaforo se encuentra completamente a un lado del plano YZ, y sobre el
// plano XZ. El lateral del semaforo partido a la mitad por el eje Y+.
// Las luces miran hacia Z-, con gravedad Y-.
//
// Estas son variables predefinidas o generadas en el
// interna de las macros que no deberian modificarse directamente.
// Si quiere cambiarlas, recurra a los modificadores.  
// #declare SPRD_DefaultTexturaPrincipal  
//      Textura principal del semaforo.
// #declare SPRD_DefaultTexturaOscura      
//      Textura para la caja oscura de luces. Las luces se ven claramente
//      gracias al contraste con el fondo.
// #declare SPRD_DefaultTexturaTornillo           
//      Textura para los tornillos.
// #declare SPRD_DefaultTexturaBoton       
//      Textura plastica para el boton.
//
// Los siguientes son los modificadores
// aplicables y redefinibles por el usuario (si se indica es default)   
// #declare SPRD_TexturaPrincipal               = texture { ... }                 
//      Textura principal del semaforo.
// #declare SPRD_TexturaOscura                  = texture { ... }
//      Textura para la caja oscura de luces. Las luces se ven claramente
//      gracias al contraste por el fondo.                                   
// #declare SPRD_TexturaTornillo                = texture { ... }
//      Textura para los tornillos.
// #declare SPRD_TexturaBoton                   = texture { ... }   
//      Textura plastica para el boton.
// #declare SPRD_PigmentRojo                    = Red;                      
//      Pigmento para la luz roja encendida. Se ve por contraste con el fondo.
// #declare SPRD_PigmentRojoApagado             = color Red transmit 0.85;   
//      Pigmento para la luz roja apagada.
// #declare SPRD_PigmentVerde                   = Green;
//      Pigmento para la luz verde encendida. Se aprecia por contraste con el fondo.
// #declare SPRD_PigmentVerdeApagado            = color Green transmit 0.95;        
//      Pigmento para la luz verde apagada.
//
// Para colocarlo simplemente
// #include "SPRD.inc"
// object        { SPRD_Semaforo( true, true, false, 5 ) }
//                                 , 
// Ejemplo con la macro detallada, mismo objeto default
// #include "SPRD.inc"   
// object                       {
//   SPRD_SemaforoPeatonalRojoDetener( true, true, false, 5,
//          1.975, 0.050, <0.280,0.420,0.100>, 0.800,    
//          SPRD_TexturaPrincipal, SPRD_TexturaOscura,
//          SPRD_TexturaTornillo, SPRD_TexturaBoton )
// }
//        
// Con modificadores
// #include "SPRD.inc"
// #include "textures.inc"
// #declare SPRD_TexturaPrincipal   = PinkAlabaster
// object        { SPRD_Semaforo( true, true, false, 5 ) }
// 
#version                        3.7;
global_settings                         {
  assumed_gamma                         1.0
}
#include "colors.inc"

#declare OjoAbsoluto            = 256;
#declare VecesCentroAbsoluto    = 10;     
#declare L                      = 0.001;
camera {
        location  <   0,  0, -( VecesCentroAbsoluto+1 )*OjoAbsoluto >*L
        direction z
        sky       y
        angle     38.74
//        look_at  <   0,  0, -VecesCentroAbsoluto*OjoAbsoluto >*L
}         
light_source    {
         < 500  , 500   , -3000 >*L
         White
}
background      {
         Gray50
}    

#include "SPRD.inc"

#local FactorAcercamiento       = 0.70;

object                          {
  SPRD_Semaforo( true, true, false, 15 )  
  translate                     -0.987*y+0.195*x
  translate       -( VecesCentroAbsoluto+1 )*( FactorAcercamiento-1 )
                        /( FactorAcercamiento )*OjoAbsoluto*L*z        
}
